aboutsummaryrefslogtreecommitdiff
path: root/src/lib/krb5/asn.1/asn1_make.h
diff options
context:
space:
mode:
authorKen Raeburn <raeburn@mit.edu>2002-09-03 00:32:14 +0000
committerKen Raeburn <raeburn@mit.edu>2002-09-03 00:32:14 +0000
commit305a721199f87a4353eabd98d9d1bb55c43c657e (patch)
tree63ba21b522a88b1de12cfaf01bf88b82c8c2e7b7 /src/lib/krb5/asn.1/asn1_make.h
parent8bdfead10df7a773e007b736219d07eeeb092161 (diff)
downloadkrb5-305a721199f87a4353eabd98d9d1bb55c43c657e.zip
krb5-305a721199f87a4353eabd98d9d1bb55c43c657e.tar.gz
krb5-305a721199f87a4353eabd98d9d1bb55c43c657e.tar.bz2
Use prototype style definitions for functions. Avoid variable name "class"
git-svn-id: svn://anonsvn.mit.edu/krb5/trunk@14810 dc483132-0cff-0310-8789-dd5450dbe970
Diffstat (limited to 'src/lib/krb5/asn.1/asn1_make.h')
-rw-r--r--src/lib/krb5/asn.1/asn1_make.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/lib/krb5/asn.1/asn1_make.h b/src/lib/krb5/asn.1/asn1_make.h
index 3fe2fca..7150549 100644
--- a/src/lib/krb5/asn.1/asn1_make.h
+++ b/src/lib/krb5/asn.1/asn1_make.h
@@ -48,20 +48,20 @@
asn1_error_code asn1_make_etag
(asn1buf *buf,
- const asn1_class class,
+ const asn1_class asn1class,
const asn1_tagnum tagnum,
const unsigned int in_len,
unsigned int *retlen);
/* requires *buf is allocated, in_len is the length of an ASN.1 encoding
which has just been inserted in *buf
modifies *buf, *retlen
- effects Inserts an explicit tag with class = class, id# = tag
+ effects Inserts an explicit tag with class = asn1class, id# = tag
length = in_len into *buf.
Returns the length of this encoding in *retlen.
Returns ENOMEM if memory runs out. */
asn1_error_code asn1_make_tag
- (asn1buf *buf, const asn1_class class,
+ (asn1buf *buf, const asn1_class asn1class,
const asn1_construction construction,
const asn1_tagnum tagnum,
const unsigned int in_len,
@@ -69,7 +69,7 @@ asn1_error_code asn1_make_tag
/* requires *buf is allocated, in_len is the length of an ASN.1 encoding
which has just been inserted in *buf
modifies *buf, *retlen
- effects Inserts the encoding of a tag with class = class,
+ effects Inserts the encoding of a tag with class = asn1class,
primitive/constructed staus = construction,
id# = tag and length = in_len into *buf.
Returns the length of this encoding in *retlen.
@@ -121,14 +121,14 @@ asn1_error_code asn1_make_length
/* "helper" procedure for asn1_make_tag */
asn1_error_code asn1_make_id
(asn1buf *buf,
- const asn1_class class,
+ const asn1_class asn1class,
const asn1_construction construction,
const asn1_tagnum tagnum,
unsigned int *retlen);
/* requires *buf is allocated, class and tagnum are appropriate for
the ASN.1 encoding which has just been inserted in *buf
modifies *buf, *retlen
- effects Inserts id octet(s) of class class and tag number tagnum
+ effects Inserts id octet(s) of class asn1class and tag number tagnum
into *buf */
#endif
@@ -121,14 +121,14 @@ asn1_error_code asn1_make_length
const asn1_tagnum tagnum,
unsigned int *retlen);
-/* requires *buf is allocated, class and tagnum are appropriate for
+/* requires *buf is allocated, asn1class and tagnum are appropriate for
the ASN.1 encoding which has just been inserted in *buf
modifies *buf, *retlen